update_color_table <- function() {
  tbl <- data.frame(color = grDevices::colors())
  tbl <- within(tbl, {
    type <- seq_len(nrow(tbl))
    red <- grDevices::col2rgb(color)[1, ]
    green <- grDevices::col2rgb(color)[2, ]
    blue <- grDevices::col2rgb(color)[3, ]
    rtf_code <- sprintf("\\red%d\\green%d\\blue%d;", red, green, blue)
  })
  tbl <- tbl[, c("color", "type", "red", "green", "blue", "rtf_code")]

  module_content <- c(
    "# Generated by scripts/update_color_table.R: do not edit by hand",
    "# Please run Rscript scripts/update_color_table.R to regenerate this file",
    "",
    "color_table = [",
    sprintf(
      '    ("%s", %d, %d, %d, %d, "%s"),',
      tbl$color, tbl$type, tbl$red, tbl$green, tbl$blue,
      gsub("\\", "\\\\", tbl$rtf_code, fixed = TRUE)
    ),
    "]",
    "",
    "# Convert to dictionaries for easier lookup",
    "name_to_type = {item[0]: item[1] for item in color_table}",
    "name_to_rgb = {item[0]: (item[2], item[3], item[4]) for item in color_table}",
    "name_to_rtf = {item[0]: item[5] for item in color_table}"
  )

  writeLines(module_content, "src/rtflite/dictionary/color_table.py")
}

update_color_table()
